# Atlan Airflow Plugin

An Airflow plugin to push data to Atlan.

## Requirements

* Python >= 3.5
* apache-airflow >= 1.10.x.

## Installation and usage

A tutorial to configure and use this plugin is available on the [Atlan Community](https://community.atlan.com/9c55898ea0364eec92df949a719842ed) Page
